//  Two traffic lights, using the standard pattern (R,R+Y,G,Y).
//
//  The GREEN TIME for each traffic light can be configured
//  A sensor signal shortens the GREEN TIME for the crossing line  
//  This might be improved (e.g. mutual blocking of sensors)
//  special light sequences are used to switch the whole system ON and OFF
//
// version 3


#include "TrafficLight.h"


// setup the LED strip
// ===================

int numberOfPixels      = 16;
int stripPin            = 26;
Adafruit_NeoPixel strip = Adafruit_NeoPixel(numberOfPixels,stripPin);


// declare the two traffic lights
// ==============================

TrafficLight tlA, tlB;


// setup
// =====

void setup() {
	
	// setup serial line for debugging
    Serial.begin(115200);
    delay(100);

	// define two traffic lights

    Serial.println("Traffic Lights starting (initially OFF) ..");

    tlA = TrafficLight( "Hasengasse", 	&strip, (const int[]) { 9,8,7}, 1 );
    tlA.setBrightness(20);
    tlA.setGreenTime(5000);

    tlB = TrafficLight( "Fuchsweg",		&strip, (const int[]) { 4,3,2}, 1);
    tlB.setBrightness(2);
    tlB.setGreenTime(10000);
    tlB.addSensor(27);

}

// functions to handle all traffic lights in the same way
// ======================================================

void allOff() {
	tlA.off();
	tlB.off();
}
void allClear() {
	tlA.clear();
	tlB.clear();
}
void allSetLamp(int lamp) {
	allClear();
	tlA.lampOn(lamp);
	tlA.show();
	tlB.lampOn(lamp);
	tlB.show();
}
void allBlink(int cycles) {
	allOff();
	for (int n=0;n<cycles;n++) {
		allSetLamp(TL_YELLOW_LAMP);
		delay(800);
		allOff();
		delay(800);
	}
}


// start up sequence : yellow blink -- steady yellow -- red
// ========================================================

void startUp() {

	// blink all traffic lights two times
	allBlink(2);

	// steady yellow
	allSetLamp(TL_YELLOW_LAMP);
	delay(2000);

	// all red for some time
	allSetLamp(TL_RED_LAMP);
	delay(2000);
}

// standardCycle
// =============
void standardCycle() {
	tlA.performCycle();
	tlB.performCycle();
}

// shut down sequence : yellow blink -- off
// ========================================

void shutDown() {
	
	// blink
	allBlink(2);

	// switch OFF
	allOff();
}


// loop
// ====

void loop() {

	// begin of day
	Serial.println("WAKING UP");
	startUp();

	// during the day (simulate two full cycles)
	Serial.println("STARTING DAYLIGHT CYCLES");
	for (int n=0;n<2;n++) {
		standardCycle();
	}

	// go asleep at night
	Serial.println("GOING ASLEEP");
	shutDown();
	delay(5000);
	
}
